=========
Briefcase
=========

Briefcase is a tool for converting a Python project into a standalone
native application. It supports producing binaries for:

* macOS, as a standalone .app
* Windows, as an MSI installer
* Linux, as a native system package
* iOS, as an Xcode project
* Android, as a Gradle project
* the Web, as a static web site using PyScript for client-side Python

It is also extensible, allowing for additional platforms and installation
formats to be produced.

Table of contents
=================

:ref:`Tutorial <tutorial>`
--------------------------

Get started with a hands-on introduction for beginners.

:ref:`How-to guides <how-to>`
-----------------------------

Guides and recipes for common problems and tasks, including how to contribute.

:ref:`Background <background>`
------------------------------

Explanation and discussion of key topics and concepts.

:ref:`Reference <reference>`
----------------------------

Technical reference - commands, modules, classes, methods.

Community
=========

Briefcase is part of the `BeeWare suite`_. You can talk to the community through:

* `@beeware@fosstodon.org on Mastodon <https://fosstodon.org/@beeware>`__

* `Discord <https://beeware.org/bee/chat/>`__

* The Briefcase `Github Discussions forum <https://github.com/beeware/briefcase/discussions>`__

.. _BeeWare suite: https://beeware.org
.. _Read The Docs: https://briefcase.readthedocs.io

.. toctree::
   :maxdepth: 2
   :hidden:
   :titlesonly:

   tutorial/index
   how-to/index
   background/index
   reference/index
